Run a hand-written tape script
vhsr_run_tape.RdEscape hatch for users who want full control over the vhs script. Pass
either a path to a .tape file or the tape contents as a string.
Value
Invisibly returns the processx::run() result.

vhsr_run_tape.RdEscape hatch for users who want full control over the vhs script. Pass
either a path to a .tape file or the tape contents as a string.
Invisibly returns the processx::run() result.